BaseAxisImpl<T extends BaseAxis, L> class abstract

Implementers

Constructors

BaseAxisImpl(T axis, {int index = 0})

Properties

axis → T
final
expanded ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
props ↔ L
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ BaseScale<dynamic, num>
getter/setter pair
scaleValue → double
no setter
scrollValue → double
no setter
show ↔ bool
getter/setter pair
titleNode ↔ AxisTitleNode
latefinal
viewRange → List<num>
返回当前轴显示的可见范围 返回值为 scale 中的range
no setter

Methods

buildScale(L props, List<DynamicData> dataSet) → BaseScale<dynamic, num>
draw(Canvas canvas, Paint paint) → void
drawAxisLine(Canvas canvas, Paint paint) → void
drawAxisName(Canvas canvas, Paint paint) → void
drawAxisTick(Canvas canvas, Paint paint) → void
layout(L layoutProps, List<DynamicData> dataSet) → void
layoutAxisName() → TextDrawConfig
measure(double parentWidth, double parentHeight) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainTicks() → List<String>
scaleDiff(num s) → void
scrollDiff(num s) → void
setScale(num scale) → void
setScroll(num scroll) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited