ChartRRectTween class

Inheritance

Constructors

ChartRRectTween(RRect begin, RRect end, {bool allowCross = false})

Properties

begin → RRect
no setterinherited
behavior → AnimationBehavior
finalinherited
curve → Curve
finalinherited
delay → Duration
finalinherited
duration → Duration
finalinherited
end → RRect
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isAnimating → bool
no setterinherited
isCompleted → bool
no setterinherited
isDismissed → bool
no setterinherited
lowerBound → double
finalinherited
reverseDuration → Duration?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → AnimationStatus
no setterinherited
statusListener ← void Function(AnimationStatus)?
no getterinherited
upperBound → double
finalinherited
value ↔ RRect
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
changeValue(RRect begin, RRect end) → void
inherited
convert(double animatorPercent) → RRect
该方法由子类复写且只能在getValue内部调用
override
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
safeGetValue(double t) → RRect
inherited
start([TickerProvider? provider, bool allowRest = false]) → void
inherited
stop([bool reset = true]) → void
inherited
toString() → String
A string representation of this object.
inherited
update(double t) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited