Legend class

Constructors

Legend({required List<LegendItem> itemList, required StyleFun<LegendItem, AreaStyle> itemStyleFun, required StyleFun<LegendItem, LabelStyle> labelStyleFun})

Properties

decoration ↔ BoxDecoration
getter/setter pair
direction ↔ Direction
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemGap ↔ num
getter/setter pair
itemList ↔ List<LegendItem>
getter/setter pair
itemStyleFun ↔ StyleFun<LegendItem, AreaStyle>
getter/setter pair
labelStyleFun ↔ StyleFun<LegendItem, LabelStyle>
getter/setter pair
padding ↔ EdgeInsetsGeometry
getter/setter pair
position ↔ ChartAlign
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scroll ↔ bool
getter/setter pair
show ↔ bool
getter/setter pair
symbolSize ↔ Size
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited