RadarGroup class

Constructors

RadarGroup(List<num> dataList, {String? id})

Properties

dataList → List<num>
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited