RectCoordinate class abstract

一个矩形范围的坐标系

Inheritance
Implementers

Constructors

RectCoordinate({SNumber leftMargin = const SNumber.number(0), SNumber topMargin = const SNumber.number(0), SNumber rightMargin = const SNumber.number(0), SNumber bottomMargin = const SNumber.number(0), SNumber? width, SNumber? height, String id = '', bool show = true})
const

Properties

bottomMargin → SNumber
final
hashCode → int
The hash code for this object.
no setterinherited
height → SNumber?
final
id → String
finalinherited
leftMargin → SNumber
final
rightMargin → SNumber
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show → bool
finalinherited
topMargin → SNumber
final
width → SNumber?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLayout() → CoordinateLayout
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited