GestureDispatcher class
手势分发器 用于处理相关的手势分发
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addGesture(
ChartGesture gesture) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDoubleTapCancel(
) → void -
onDoubleTapDown(
TapDownDetails details) → void -
onDoubleTapUp(
TapUpDetails details) → void -
onHoverEnd(
PointerExitEvent event) → void -
onHoverMove(
PointerHoverEvent event) → void -
onHoverStart(
PointerEnterEvent event) → void -
onLongPressCancel(
) → void -
onLongPressEnd(
LongPressEndDetails details) → void -
onLongPressMove(
LongPressMoveUpdateDetails details) → void -
onLongPressStart(
LongPressStartDetails details) → void -
onScaleEnd(
ScaleEndDetails details) → void -
onScaleStart(
ScaleStartDetails details) → void -
onScaleUpdate(
ScaleUpdateDetails details) → void -
onTapCancel(
) → void -
onTapDown(
TapDownDetails details) → void -
onTapUp(
TapUpDetails details) → void -
removeGesture(
ChartGesture gesture) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited